# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import location_pb2 as v1_dot_rules_dot_location__pb2


class LocationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LocationCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationCreate",
            request_serializer=v1_dot_rules_dot_location__pb2.LocationCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_location__pb2.LocationCreateResponse.FromString,
        )
        self.LocationRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationRead",
            request_serializer=v1_dot_rules_dot_location__pb2.LocationReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_location__pb2.LocationReadResponse.FromString,
        )
        self.LocationUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationUpdate",
            request_serializer=v1_dot_rules_dot_location__pb2.LocationUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_location__pb2.LocationUpdateResponse.FromString,
        )
        self.LocationDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationDelete",
            request_serializer=v1_dot_rules_dot_location__pb2.LocationDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_location__pb2.LocationDeleteResponse.FromString,
        )


class LocationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LocationCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LocationDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_LocationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "LocationCreate": grpc.unary_unary_rpc_method_handler(
            servicer.LocationCreate,
            request_deserializer=v1_dot_rules_dot_location__pb2.LocationCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_location__pb2.LocationCreateResponse.SerializeToString,
        ),
        "LocationRead": grpc.unary_unary_rpc_method_handler(
            servicer.LocationRead,
            request_deserializer=v1_dot_rules_dot_location__pb2.LocationReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_location__pb2.LocationReadResponse.SerializeToString,
        ),
        "LocationUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.LocationUpdate,
            request_deserializer=v1_dot_rules_dot_location__pb2.LocationUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_location__pb2.LocationUpdateResponse.SerializeToString,
        ),
        "LocationDelete": grpc.unary_unary_rpc_method_handler(
            servicer.LocationDelete,
            request_deserializer=v1_dot_rules_dot_location__pb2.LocationDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_location__pb2.LocationDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.location.LocationService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class LocationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LocationCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationCreate",
            v1_dot_rules_dot_location__pb2.LocationCreateRequest.SerializeToString,
            v1_dot_rules_dot_location__pb2.LocationCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationRead",
            v1_dot_rules_dot_location__pb2.LocationReadRequest.SerializeToString,
            v1_dot_rules_dot_location__pb2.LocationReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationUpdate",
            v1_dot_rules_dot_location__pb2.LocationUpdateRequest.SerializeToString,
            v1_dot_rules_dot_location__pb2.LocationUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LocationDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.location.LocationService/LocationDelete",
            v1_dot_rules_dot_location__pb2.LocationDeleteRequest.SerializeToString,
            v1_dot_rules_dot_location__pb2.LocationDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/category.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/rules/category.proto\x12"pro.omni.oms.api.v1.rules.category\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xf7\x01\n\x08\x43\x61tegory\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x15\n\rfamily_doc_id\x18\x04 \x01(\t\x12\x12\n\ngroup_code\x18\x05 \x01(\t\x12\x16\n\x0e\x61ttribute_code\x18\x06 \x01(\t\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x08 \x01(\t\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x9a\x01\n\x15\x43\x61tegoryCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x18\n\x10\x61ttribute_doc_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16\x43\x61tegoryCreateResponse\x12>\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.category.Category\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf1\x02\n\x13\x43\x61tegoryReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xde\x01\n\x14\x43\x61tegoryReadResponse\x12@\n\ncategories\x18\x01 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.category.Category\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8f\x01\n\x15\x43\x61tegoryUpdateRequest\x12>\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.category.Category\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16\x43\x61tegoryUpdateResponse\x12>\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.category.Category\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"[\n\x15\x43\x61tegoryDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16\x43\x61tegoryDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xbb\x04\n\x0f\x43\x61tegoryService\x12\x89\x01\n\x0e\x43\x61tegoryCreate\x12\x39.pro.omni.oms.api.v1.rules.category.CategoryCreateRequest\x1a:.pro.omni.oms.api.v1.rules.category.CategoryCreateResponse"\x00\x12\x83\x01\n\x0c\x43\x61tegoryRead\x12\x37.pro.omni.oms.api.v1.rules.category.CategoryReadRequest\x1a\x38.pro.omni.oms.api.v1.rules.category.CategoryReadResponse"\x00\x12\x89\x01\n\x0e\x43\x61tegoryUpdate\x12\x39.pro.omni.oms.api.v1.rules.category.CategoryUpdateRequest\x1a:.pro.omni.oms.api.v1.rules.category.CategoryUpdateResponse"\x00\x12\x89\x01\n\x0e\x43\x61tegoryDelete\x12\x39.pro.omni.oms.api.v1.rules.category.CategoryDeleteRequest\x1a:.pro.omni.oms.api.v1.rules.category.CategoryDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.category_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CATEGORY"]._serialized_start = 115
    _globals["_CATEGORY"]._serialized_end = 362
    _globals["_CATEGORYCREATEREQUEST"]._serialized_start = 365
    _globals["_CATEGORYCREATEREQUEST"]._serialized_end = 519
    _globals["_CATEGORYCREATERESPONSE"]._serialized_start = 522
    _globals["_CATEGORYCREATERESPONSE"]._serialized_end = 685
    _globals["_CATEGORYREADREQUEST"]._serialized_start = 688
    _globals["_CATEGORYREADREQUEST"]._serialized_end = 1057
    _globals["_CATEGORYREADRESPONSE"]._serialized_start = 1060
    _globals["_CATEGORYREADRESPONSE"]._serialized_end = 1282
    _globals["_CATEGORYUPDATEREQUEST"]._serialized_start = 1285
    _globals["_CATEGORYUPDATEREQUEST"]._serialized_end = 1428
    _globals["_CATEGORYUPDATERESPONSE"]._serialized_start = 1431
    _globals["_CATEGORYUPDATERESPONSE"]._serialized_end = 1594
    _globals["_CATEGORYDELETEREQUEST"]._serialized_start = 1596
    _globals["_CATEGORYDELETEREQUEST"]._serialized_end = 1687
    _globals["_CATEGORYDELETERESPONSE"]._serialized_start = 1689
    _globals["_CATEGORYDELETERESPONSE"]._serialized_end = 1788
    _globals["_CATEGORYSERVICE"]._serialized_start = 1791
    _globals["_CATEGORYSERVICE"]._serialized_end = 2362
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/order_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.sales import order_pb2 as v1_dot_sales_dot_order__pb2
from omni.pro.protos.v1.sales import product_pb2 as v1_dot_sales_dot_product__pb2
from omni.pro.protos.v1.sales import tax_pb2 as v1_dot_sales_dot_tax__pb2
from omni.pro.protos.v1.sales import uom_pb2 as v1_dot_sales_dot_uom__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19v1/sales/order_line.proto\x12$pro.omni.oms.api.v1.sales.order.line\x1a\x11\x63ommon/base.proto\x1a\x16v1/sales/product.proto\x1a\x12v1/sales/uom.proto\x1a\x14v1/sales/order.proto\x1a\x12v1/sales/tax.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xbc\x03\n\tOrderLine\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x35\n\x05order\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.order.Order\x12;\n\x07product\x18\x03 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.product.Product\x12\x10\n\x08quantity\x18\x04 \x01(\x02\x12/\n\x03uom\x18\x05 \x01(\x0b\x32".pro.omni.oms.api.v1.sales.uom.Uom\x12\x12\n\nprice_unit\x18\x06 \x01(\x02\x12/\n\x03tax\x18\x07 \x01(\x0b\x32".pro.omni.oms.api.v1.sales.tax.Tax\x12\x10\n\x08\x64iscount\x18\x08 \x01(\x02\x12\x13\n\x0bprice_total\x18\t \x01(\x02\x12*\n\x06\x61\x63tive\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0b \x01(\t\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf8\x01\n\x16OrderLineCreateRequest\x12\x10\n\x08order_id\x18\x01 \x01(\x05\x12\x12\n\nproduct_id\x18\x02 \x01(\t\x12\x10\n\x08quantity\x18\x03 \x01(\x02\x12\x0e\n\x06uom_id\x18\x04 \x01(\t\x12\x12\n\nprice_unit\x18\x05 \x01(\x02\x12\x0e\n\x06tax_id\x18\x06 \x01(\x05\x12\x10\n\x08\x64iscount\x18\x07 \x01(\x02\x12\x13\n\x0bprice_total\x18\x08 \x01(\x02\x12\x13\n\x0b\x65xternal_id\x18\t \x01(\t\x12\x36\n\x07\x63ontext\x18\n \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa9\x01\n\x17OrderLineCreateResponse\x12\x43\n\norder_line\x18\x01 \x01(\x0b\x32/.pro.omni.oms.api.v1.sales.order.line.OrderLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf2\x02\n\x14OrderLineReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n\x15OrderLineReadResponse\x12\x44\n\x0border_lines\x18\x01 \x03(\x0b\x32/.pro.omni.oms.api.v1.sales.order.line.OrderLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\x95\x01\n\x16OrderLineUpdateRequest\x12\x43\n\norder_line\x18\x01 \x01(\x0b\x32/.pro.omni.oms.api.v1.sales.order.line.OrderLine\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa9\x01\n\x17OrderLineUpdateResponse\x12\x43\n\norder_line\x18\x01 \x01(\x0b\x32/.pro.omni.oms.api.v1.sales.order.line.OrderLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\\\n\x16OrderLineDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17OrderLineDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd8\x04\n\x10OrderLineService\x12\x90\x01\n\x0fOrderLineCreate\x12<.pro.omni.oms.api.v1.sales.order.line.OrderLineCreateRequest\x1a=.pro.omni.oms.api.v1.sales.order.line.OrderLineCreateResponse"\x00\x12\x8a\x01\n\rOrderLineRead\x12:.pro.omni.oms.api.v1.sales.order.line.OrderLineReadRequest\x1a;.pro.omni.oms.api.v1.sales.order.line.OrderLineReadResponse"\x00\x12\x90\x01\n\x0fOrderLineUpdate\x12<.pro.omni.oms.api.v1.sales.order.line.OrderLineUpdateRequest\x1a=.pro.omni.oms.api.v1.sales.order.line.OrderLineUpdateResponse"\x00\x12\x90\x01\n\x0fOrderLineDelete\x12<.pro.omni.oms.api.v1.sales.order.line.OrderLineDeleteRequest\x1a=.pro.omni.oms.api.v1.sales.order.line.OrderLineDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.order_line_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_ORDERLINE"]._serialized_start = 205
    _globals["_ORDERLINE"]._serialized_end = 649
    _globals["_ORDERLINECREATEREQUEST"]._serialized_start = 652
    _globals["_ORDERLINECREATEREQUEST"]._serialized_end = 900
    _globals["_ORDERLINECREATERESPONSE"]._serialized_start = 903
    _globals["_ORDERLINECREATERESPONSE"]._serialized_end = 1072
    _globals["_ORDERLINEREADREQUEST"]._serialized_start = 1075
    _globals["_ORDERLINEREADREQUEST"]._serialized_end = 1445
    _globals["_ORDERLINEREADRESPONSE"]._serialized_start = 1448
    _globals["_ORDERLINEREADRESPONSE"]._serialized_end = 1675
    _globals["_ORDERLINEUPDATEREQUEST"]._serialized_start = 1678
    _globals["_ORDERLINEUPDATEREQUEST"]._serialized_end = 1827
    _globals["_ORDERLINEUPDATERESPONSE"]._serialized_start = 1830
    _globals["_ORDERLINEUPDATERESPONSE"]._serialized_end = 1999
    _globals["_ORDERLINEDELETEREQUEST"]._serialized_start = 2001
    _globals["_ORDERLINEDELETEREQUEST"]._serialized_end = 2093
    _globals["_ORDERLINEDELETERESPONSE"]._serialized_start = 2095
    _globals["_ORDERLINEDELETERESPONSE"]._serialized_end = 2195
    _globals["_ORDERLINESERVICE"]._serialized_start = 2198
    _globals["_ORDERLINESERVICE"]._serialized_end = 2798
# @@protoc_insertion_point(module_scope)



import boto3
from botocore.exceptions import ClientError
from omni.pro.util import HTTPStatus, generate_strong_password, nested


class AWSClient(object):
    def __init__(
        self, service_name: str, region_name: str, aws_access_key_id: str, aws_secret_access_key: str, **kwargs
    ) -> None:
        """
        :type service_name: str
        :param service_name: AWS service name
        :type region_name: str
        :param region_name: AWS region name
        :type aws_access_key_id: str
        :param aws_access_key_id: AWS access key id
        :type aws_secret_access_key: str
        :param aws_secret_access_key: AWS secret access key
        Example:
            service_name = "service_name"
            region_name = "us-east-1"
            aws_access_key_id = "AKIAIOSFODNN7EXAMPLE"
            aws_secret_access_key = "wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY"
        """
        self._client = boto3.client(
            service_name=service_name,
            region_name=region_name,
            aws_access_key_id=aws_access_key_id,
            aws_secret_access_key=aws_secret_access_key,
            **kwargs,
        )

    def get_client(self):
        return self._client

    client = property(get_client)


class AWSCognitoClient(AWSClient):
    def __init__(
        self,
        region_name: str,
        aws_access_key_id: str,
        aws_secret_access_key: str,
        user_pool_id: str,
        client_id: str,
        **kwargs,
    ) -> None:
        """
        :type user_pool_id: str
        :param user_pool_id: AWS user pool id
        :type client_id: str
        :param client_id: AWS client id
        Example:
            service_name = "cognito-idp"
            region_name = "us-east-1"
            user_pool_id = "us-east-1_123456789"
            client_id = "1234567890123456789012"
        """
        super().__init__(
            service_name="cognito-idp",
            region_name=region_name,
            aws_access_key_id=aws_access_key_id,
            aws_secret_access_key=aws_secret_access_key,
            **kwargs,
        )
        self.user_pool_id = user_pool_id
        self.client_id = client_id

    def get_user(self, username: str) -> dict:
        return self.client.admin_get_user(UserPoolId=self.user_pool_id, Username=username)

    def create_user(
        self, username: str, password: str, name: str, email: str, tenant: str, language_code: str, timezone_code: str
    ) -> dict:
        response = self.client.admin_create_user(
            UserPoolId=self.user_pool_id,
            Username=username,
            TemporaryPassword=generate_strong_password(),
            UserAttributes=[
                {"Name": "name", "Value": name},
                {"Name": "email", "Value": email},
                {"Name": "custom:tenant", "Value": tenant},
                {"Name": "locale", "Value": language_code},
                {"Name": "zoneinfo", "Value": timezone_code},
            ],
        )
        self.set_user_password(username=username, password=password)
        return response

    def delete_user(self, username: str) -> dict:
        return self.client.admin_delete_user(UserPoolId=self.user_pool_id, Username=username)

    def set_user_password(self, username: str, password: str) -> None:
        self.client.admin_set_user_password(
            UserPoolId=self.user_pool_id, Username=username, Password=password, Permanent=True
        )

    def update_user(self, username: str, name: str, language_code: str, timezone_code: str) -> dict:
        return self._update_attributes(
            username=username,
            attributes=[
                {"Name": "name", "Value": name},
                {"Name": "locale", "Value": language_code},
                {"Name": "zoneinfo", "Value": timezone_code},
            ],
        )

    def update_email(self, username, email: str) -> dict:
        return self._update_attributes(username=username, attributes=[{"Name": "email", "Value": email}])

    def _update_attributes(self, username: str, attributes: list) -> dict:
        response = self.client.admin_update_user_attributes(
            UserPoolId=self.user_pool_id,
            Username=username,
            UserAttributes=attributes,
        )
        return nested(response, "ResponseMetadata.HTTPStatusCode") == HTTPStatus.OK, response

    def list_users(self, filter: str, limit: int, offset: int, pagination_token: str = None) -> dict:
        paginator = self.client.get_paginator("list_users")
        pag_config = {"MaxItems": int(limit), "PageSize": int(offset)}
        if pagination_token:
            pag_config["StartingToken"] = pagination_token
        page_iterator = paginator.paginate(
            UserPoolId=self.user_pool_id,
            Filter=f'name ^= "{filter}"',
            PaginationConfig=pag_config,
        )
        starting_token = None
        first_page = True
        list_user = []
        for page in page_iterator:
            users = page["Users"]
            if first_page:
                first_page = False
            else:
                if not starting_token:
                    starting_token = page.get("PaginationToken")

            for user in users:
                list_user.append(user)
        return list_user, starting_token

    def init_auth(self, username: str, password: str) -> dict:
        auth_result = {}
        status_code = HTTPStatus.BAD_REQUEST
        message = ""
        try:
            result = self.get_client().initiate_auth(
                ClientId=self.client_id,
                AuthFlow="USER_PASSWORD_AUTH",
                AuthParameters={
                    "USERNAME": username,
                    "PASSWORD": password,
                },
            )
        except ClientError as e:
            if e.response["Error"]["Code"] == "NotAuthorizedException":
                status_code = HTTPStatus.UNAUTHORIZED
                message = "Invalid auth data"
            elif e.response["Error"]["Code"] == "InvalidParameterException":
                status_code = HTTPStatus.BAD_REQUEST
                message = "Missing or empty parameters in request"
            else:
                status_code = HTTPStatus.UNAUTHORIZED
                message = str(e)
        else:
            message = "Success"
            status_code = HTTPStatus.OK
            auth_result = {
                "token": result["AuthenticationResult"]["IdToken"],
                "refresh_token": result["AuthenticationResult"]["RefreshToken"],
                "expires_in": result["AuthenticationResult"]["ExpiresIn"],
            }

        return status_code, auth_result, message

    def refresh_token(self, refresh_token):
        auth_result = {}
        status_code = HTTPStatus.BAD_REQUEST
        message = ""
        try:
            new_tokens_response = self.get_client().initiate_auth(
                ClientId=self.client_id,
                AuthFlow="REFRESH_TOKEN_AUTH",
                AuthParameters={"REFRESH_TOKEN": refresh_token},
            )
        except ClientError as e:
            status_code = HTTPStatus.UNAUTHORIZED
            if e.response["Error"]["Code"] == "NotAuthorizedException":
                message = "Invalid refresh token"
            else:
                message = str(e)
        else:
            status_code = HTTPStatus.OK
            message = "Success"
            auth_result = {
                "token": new_tokens_response["AuthenticationResult"]["IdToken"],
                "expires_in": new_tokens_response["AuthenticationResult"]["ExpiresIn"],
            }
        return status_code, auth_result, message


class S3Client(AWSClient):
    def __init__(
        self, service_name: str, region_name: str, aws_access_key_id: str, aws_secret_access_key: str, **kwargs
    ) -> None:
        super().__init__(service_name, region_name, aws_access_key_id, aws_secret_access_key, **kwargs)


class AWSCloudMap(AWSClient):
    def __init__(
        self,
        region_name: str,
        namespace_name: str,
        service_name: str,
        aws_access_key_id: str,
        aws_secret_access_key: str,
        **kwargs,
    ):
        super().__init__(
            service_name="servicediscovery",
            region_name=region_name,
            aws_access_key_id=aws_access_key_id,
            aws_secret_access_key=aws_secret_access_key,
            **kwargs,
        )
        self.namespace_name = namespace_name
        self.service_name = service_name

    def discover_instances(self):
        response = self.client.discover_instances(
            NamespaceName=self.namespace_name,
            ServiceName=self.service_name,
        )
        if not response.get("Instances"):
            raise Exception("No instances found")

        return response.get("Instances")

    def get_redis_config(self):
        instances = self.discover_instances()
        instance = instances[0]
        return {
            "host": instance.get("Attributes").get("host"),
            "port": int(instance.get("Attributes").get("port") or 6379),
            "db": int(instance.get("Attributes").get("db") or 0),
        }



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import import_export_pb2 as v1_dot_utilities_dot_import__export__pb2


class ImportExportServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ImportExportCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportCreate",
            request_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportCreateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportCreateResponse.FromString,
        )
        self.ImportExportRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportRead",
            request_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportReadResponse.FromString,
        )
        self.ImportExportUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportUpdate",
            request_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateResponse.FromString,
        )
        self.ImportExportDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportDelete",
            request_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteResponse.FromString,
        )


class ImportExportServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ImportExportCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ImportExportRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ImportExportUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ImportExportDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ImportExportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ImportExportCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ImportExportCreate,
            request_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportCreateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportCreateResponse.SerializeToString,
        ),
        "ImportExportRead": grpc.unary_unary_rpc_method_handler(
            servicer.ImportExportRead,
            request_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportReadResponse.SerializeToString,
        ),
        "ImportExportUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ImportExportUpdate,
            request_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateResponse.SerializeToString,
        ),
        "ImportExportDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ImportExportDelete,
            request_deserializer=v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.import_export.ImportExportService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ImportExportService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ImportExportCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportCreate",
            v1_dot_utilities_dot_import__export__pb2.ImportExportCreateRequest.SerializeToString,
            v1_dot_utilities_dot_import__export__pb2.ImportExportCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ImportExportRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportRead",
            v1_dot_utilities_dot_import__export__pb2.ImportExportReadRequest.SerializeToString,
            v1_dot_utilities_dot_import__export__pb2.ImportExportReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ImportExportUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportUpdate",
            v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_import__export__pb2.ImportExportUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ImportExportDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.import_export.ImportExportService/ImportExportDelete",
            v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_import__export__pb2.ImportExportDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_time_delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n,v1/rules/delivery_time_delivery_method.proto\x12\x37pro.omni.oms.api.v1.rules.delivery_time_delivery_method\x1a\x11\x63ommon/base.proto"\xc4\x01\n\x1a\x44\x65liveryTimeDeliveryMethod\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x18\n\x10\x64\x65livery_time_id\x18\x02 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xac\x01\n\'DeliveryTimeDeliveryMethodCreateRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf1\x01\n(DeliveryTimeDeliveryMethodCreateResponse\x12z\n\x1d\x64\x65livery_time_delivery_method\x18\x01 \x01(\x0b\x32S.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x83\x03\n%DeliveryTimeDeliveryMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xaa\x02\n&DeliveryTimeDeliveryMethodReadResponse\x12z\n\x1d\x64\x65livery_time_delivery_method\x18\x01 \x03(\x0b\x32S.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethod\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xdd\x01\n\'DeliveryTimeDeliveryMethodUpdateRequest\x12z\n\x1d\x64\x65livery_time_delivery_method\x18\x01 \x01(\x0b\x32S.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf1\x01\n(DeliveryTimeDeliveryMethodUpdateResponse\x12z\n\x1d\x64\x65livery_time_delivery_method\x18\x01 \x01(\x0b\x32S.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"m\n\'DeliveryTimeDeliveryMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"u\n(DeliveryTimeDeliveryMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xcd\x07\n!DeliveryTimeDeliveryMethodService\x12\xe9\x01\n DeliveryTimeDeliveryMethodCreate\x12`.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodCreateRequest\x1a\x61.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodCreateResponse"\x00\x12\xe3\x01\n\x1e\x44\x65liveryTimeDeliveryMethodRead\x12^.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodReadRequest\x1a_.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodReadResponse"\x00\x12\xe9\x01\n DeliveryTimeDeliveryMethodUpdate\x12`.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodUpdateRequest\x1a\x61.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodUpdateResponse"\x00\x12\xe9\x01\n DeliveryTimeDeliveryMethodDelete\x12`.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodDeleteRequest\x1a\x61.pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_time_delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYTIMEDELIVERYMETHOD"]._serialized_start = 125
    _globals["_DELIVERYTIMEDELIVERYMETHOD"]._serialized_end = 321
    _globals["_DELIVERYTIMEDELIVERYMETHODCREATEREQUEST"]._serialized_start = 324
    _globals["_DELIVERYTIMEDELIVERYMETHODCREATEREQUEST"]._serialized_end = 496
    _globals["_DELIVERYTIMEDELIVERYMETHODCREATERESPONSE"]._serialized_start = 499
    _globals["_DELIVERYTIMEDELIVERYMETHODCREATERESPONSE"]._serialized_end = 740
    _globals["_DELIVERYTIMEDELIVERYMETHODREADREQUEST"]._serialized_start = 743
    _globals["_DELIVERYTIMEDELIVERYMETHODREADREQUEST"]._serialized_end = 1130
    _globals["_DELIVERYTIMEDELIVERYMETHODREADRESPONSE"]._serialized_start = 1133
    _globals["_DELIVERYTIMEDELIVERYMETHODREADRESPONSE"]._serialized_end = 1431
    _globals["_DELIVERYTIMEDELIVERYMETHODUPDATEREQUEST"]._serialized_start = 1434
    _globals["_DELIVERYTIMEDELIVERYMETHODUPDATEREQUEST"]._serialized_end = 1655
    _globals["_DELIVERYTIMEDELIVERYMETHODUPDATERESPONSE"]._serialized_start = 1658
    _globals["_DELIVERYTIMEDELIVERYMETHODUPDATERESPONSE"]._serialized_end = 1899
    _globals["_DELIVERYTIMEDELIVERYMETHODDELETEREQUEST"]._serialized_start = 1901
    _globals["_DELIVERYTIMEDELIVERYMETHODDELETEREQUEST"]._serialized_end = 2010
    _globals["_DELIVERYTIMEDELIVERYMETHODDELETERESPONSE"]._serialized_start = 2012
    _globals["_DELIVERYTIMEDELIVERYMETHODDELETERESPONSE"]._serialized_end = 2129
    _globals["_DELIVERYTIMEDELIVERYMETHODSERVICE"]._serialized_start = 2132
    _globals["_DELIVERYTIMEDELIVERYMETHODSERVICE"]._serialized_end = 3105
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/product.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/stock/product.proto\x12!pro.omni.oms.api.v1.stock.product\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xe4\x01\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x16\n\x0eproduct_doc_id\x18\x02 \x01(\t\x12\x17\n\x0ftemplate_doc_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb0\x01\n\x14ProductCreateRequest\x12\x16\n\x0eproduct_doc_id\x18\x01 \x01(\t\x12\x17\n\x0ftemplate_doc_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15ProductCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07product\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.product.Product"\xf0\x02\n\x12ProductReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd9\x01\n\x13ProductReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12<\n\x08products\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.stock.product.Product"\x8b\x01\n\x14ProductUpdateRequest\x12;\n\x07product\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.product.Product\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15ProductUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07product\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.product.Product"Z\n\x14ProductDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15ProductDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xa5\x04\n\x0eProductService\x12\x84\x01\n\rProductCreate\x12\x37.pro.omni.oms.api.v1.stock.product.ProductCreateRequest\x1a\x38.pro.omni.oms.api.v1.stock.product.ProductCreateResponse"\x00\x12~\n\x0bProductRead\x12\x35.pro.omni.oms.api.v1.stock.product.ProductReadRequest\x1a\x36.pro.omni.oms.api.v1.stock.product.ProductReadResponse"\x00\x12\x84\x01\n\rProductUpdate\x12\x37.pro.omni.oms.api.v1.stock.product.ProductUpdateRequest\x1a\x38.pro.omni.oms.api.v1.stock.product.ProductUpdateResponse"\x00\x12\x84\x01\n\rProductDelete\x12\x37.pro.omni.oms.api.v1.stock.product.ProductDeleteRequest\x1a\x38.pro.omni.oms.api.v1.stock.product.ProductDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.product_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PRODUCT"]._serialized_start = 113
    _globals["_PRODUCT"]._serialized_end = 341
    _globals["_PRODUCTCREATEREQUEST"]._serialized_start = 344
    _globals["_PRODUCTCREATEREQUEST"]._serialized_end = 520
    _globals["_PRODUCTCREATERESPONSE"]._serialized_start = 523
    _globals["_PRODUCTCREATERESPONSE"]._serialized_end = 682
    _globals["_PRODUCTREADREQUEST"]._serialized_start = 685
    _globals["_PRODUCTREADREQUEST"]._serialized_end = 1053
    _globals["_PRODUCTREADRESPONSE"]._serialized_start = 1056
    _globals["_PRODUCTREADRESPONSE"]._serialized_end = 1273
    _globals["_PRODUCTUPDATEREQUEST"]._serialized_start = 1276
    _globals["_PRODUCTUPDATEREQUEST"]._serialized_end = 1415
    _globals["_PRODUCTUPDATERESPONSE"]._serialized_start = 1418
    _globals["_PRODUCTUPDATERESPONSE"]._serialized_end = 1577
    _globals["_PRODUCTDELETEREQUEST"]._serialized_start = 1579
    _globals["_PRODUCTDELETEREQUEST"]._serialized_end = 1669
    _globals["_PRODUCTDELETERESPONSE"]._serialized_start = 1671
    _globals["_PRODUCTDELETERESPONSE"]._serialized_end = 1769
    _globals["_PRODUCTSERVICE"]._serialized_start = 1772
    _globals["_PRODUCTSERVICE"]._serialized_end = 2321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/sequence.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bv1/utilities/sequence.proto\x12&pro.omni.oms.api.v1.utilities.sequence\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb3\x02\n\x08Sequence\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x16\n\x0eimplementation\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\x12\x0e\n\x06suffix\x18\x06 \x01(\t\x12\x0f\n\x07padding\x18\x07 \x01(\x02\x12\x18\n\x10number_increment\x18\x08 \x01(\x05\x12\x1a\n\x12number_next_actual\x18\t \x01(\x05\x12*\n\x06\x61\x63tive\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0b \x01(\t\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xff\x01\n\x15SequenceCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x16\n\x0eimplementation\x18\x03 \x01(\t\x12\x0e\n\x06prefix\x18\x04 \x01(\t\x12\x0e\n\x06suffix\x18\x05 \x01(\t\x12\x0f\n\x07padding\x18\x06 \x01(\x02\x12\x18\n\x10number_increment\x18\x07 \x01(\x05\x12\x1a\n\x12number_next_actual\x18\x08 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\t \x01(\t\x12\x36\n\x07\x63ontext\x18\n \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x16SequenceCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08sequence\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.sequence.Sequence"\xf1\x02\n\x13SequenceReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe1\x01\n\x14SequenceReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x43\n\tsequences\x18\x03 \x03(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.sequence.Sequence"\x93\x01\n\x15SequenceUpdateRequest\x12\x42\n\x08sequence\x18\x01 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.sequence.Sequence\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x16SequenceUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08sequence\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.sequence.Sequence"[\n\x15SequenceDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16SequenceDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"U\n\x0fNextByIdRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"Y\n\x11NextByCodeRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x1c\n\x0cNextResponse\x12\x0c\n\x04next\x18\x01 \x01(\t2\xd9\x06\n\x0fSequenceService\x12\x91\x01\n\x0eSequenceCreate\x12=.pro.omni.oms.api.v1.utilities.sequence.SequenceCreateRequest\x1a>.pro.omni.oms.api.v1.utilities.sequence.SequenceCreateResponse"\x00\x12\x8b\x01\n\x0cSequenceRead\x12;.pro.omni.oms.api.v1.utilities.sequence.SequenceReadRequest\x1a<.pro.omni.oms.api.v1.utilities.sequence.SequenceReadResponse"\x00\x12\x91\x01\n\x0eSequenceUpdate\x12=.pro.omni.oms.api.v1.utilities.sequence.SequenceUpdateRequest\x1a>.pro.omni.oms.api.v1.utilities.sequence.SequenceUpdateResponse"\x00\x12\x91\x01\n\x0eSequenceDelete\x12=.pro.omni.oms.api.v1.utilities.sequence.SequenceDeleteRequest\x1a>.pro.omni.oms.api.v1.utilities.sequence.SequenceDeleteResponse"\x00\x12{\n\x08NextById\x12\x37.pro.omni.oms.api.v1.utilities.sequence.NextByIdRequest\x1a\x34.pro.omni.oms.api.v1.utilities.sequence.NextResponse"\x00\x12\x7f\n\nNextByCode\x12\x39.pro.omni.oms.api.v1.utilities.sequence.NextByCodeRequest\x1a\x34.pro.omni.oms.api.v1.utilities.sequence.NextResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.sequence_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SEQUENCE"]._serialized_start = 123
    _globals["_SEQUENCE"]._serialized_end = 430
    _globals["_SEQUENCECREATEREQUEST"]._serialized_start = 433
    _globals["_SEQUENCECREATEREQUEST"]._serialized_end = 688
    _globals["_SEQUENCECREATERESPONSE"]._serialized_start = 691
    _globals["_SEQUENCECREATERESPONSE"]._serialized_end = 858
    _globals["_SEQUENCEREADREQUEST"]._serialized_start = 861
    _globals["_SEQUENCEREADREQUEST"]._serialized_end = 1230
    _globals["_SEQUENCEREADRESPONSE"]._serialized_start = 1233
    _globals["_SEQUENCEREADRESPONSE"]._serialized_end = 1458
    _globals["_SEQUENCEUPDATEREQUEST"]._serialized_start = 1461
    _globals["_SEQUENCEUPDATEREQUEST"]._serialized_end = 1608
    _globals["_SEQUENCEUPDATERESPONSE"]._serialized_start = 1611
    _globals["_SEQUENCEUPDATERESPONSE"]._serialized_end = 1778
    _globals["_SEQUENCEDELETEREQUEST"]._serialized_start = 1780
    _globals["_SEQUENCEDELETEREQUEST"]._serialized_end = 1871
    _globals["_SEQUENCEDELETERESPONSE"]._serialized_start = 1873
    _globals["_SEQUENCEDELETERESPONSE"]._serialized_end = 1972
    _globals["_NEXTBYIDREQUEST"]._serialized_start = 1974
    _globals["_NEXTBYIDREQUEST"]._serialized_end = 2059
    _globals["_NEXTBYCODEREQUEST"]._serialized_start = 2061
    _globals["_NEXTBYCODEREQUEST"]._serialized_end = 2150
    _globals["_NEXTRESPONSE"]._serialized_start = 2152
    _globals["_NEXTRESPONSE"]._serialized_end = 2180
    _globals["_SEQUENCESERVICE"]._serialized_start = 2183
    _globals["_SEQUENCESERVICE"]._serialized_end = 3040
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/attachment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19v1/stock/attachment.proto\x12$pro.omni.oms.api.v1.stock.attachment\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc6\x01\n\nAttachment\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64oc_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x92\x01\n\x17\x41ttachmentCreateRequest\x12\x0e\n\x06\x64oc_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xab\x01\n\x18\x41ttachmentCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x44\n\nattachment\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.stock.attachment.Attachment"\xf3\x02\n\x15\x41ttachmentReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe5\x01\n\x16\x41ttachmentReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x45\n\x0b\x61ttachments\x18\x03 \x03(\x0b\x32\x30.pro.omni.oms.api.v1.stock.attachment.Attachment"\x97\x01\n\x17\x41ttachmentUpdateRequest\x12\x44\n\nattachment\x18\x01 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.stock.attachment.Attachment\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xab\x01\n\x18\x41ttachmentUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x44\n\nattachment\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.stock.attachment.Attachment"]\n\x17\x41ttachmentDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"e\n\x18\x41ttachmentDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe5\x04\n\x11\x41ttachmentService\x12\x93\x01\n\x10\x41ttachmentCreate\x12=.pro.omni.oms.api.v1.stock.attachment.AttachmentCreateRequest\x1a>.pro.omni.oms.api.v1.stock.attachment.AttachmentCreateResponse"\x00\x12\x8d\x01\n\x0e\x41ttachmentRead\x12;.pro.omni.oms.api.v1.stock.attachment.AttachmentReadRequest\x1a<.pro.omni.oms.api.v1.stock.attachment.AttachmentReadResponse"\x00\x12\x93\x01\n\x10\x41ttachmentUpdate\x12=.pro.omni.oms.api.v1.stock.attachment.AttachmentUpdateRequest\x1a>.pro.omni.oms.api.v1.stock.attachment.AttachmentUpdateResponse"\x00\x12\x93\x01\n\x10\x41ttachmentDelete\x12=.pro.omni.oms.api.v1.stock.attachment.AttachmentDeleteRequest\x1a>.pro.omni.oms.api.v1.stock.attachment.AttachmentDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.attachment_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_ATTACHMENT"]._serialized_start = 119
    _globals["_ATTACHMENT"]._serialized_end = 317
    _globals["_ATTACHMENTCREATEREQUEST"]._serialized_start = 320
    _globals["_ATTACHMENTCREATEREQUEST"]._serialized_end = 466
    _globals["_ATTACHMENTCREATERESPONSE"]._serialized_start = 469
    _globals["_ATTACHMENTCREATERESPONSE"]._serialized_end = 640
    _globals["_ATTACHMENTREADREQUEST"]._serialized_start = 643
    _globals["_ATTACHMENTREADREQUEST"]._serialized_end = 1014
    _globals["_ATTACHMENTREADRESPONSE"]._serialized_start = 1017
    _globals["_ATTACHMENTREADRESPONSE"]._serialized_end = 1246
    _globals["_ATTACHMENTUPDATEREQUEST"]._serialized_start = 1249
    _globals["_ATTACHMENTUPDATEREQUEST"]._serialized_end = 1400
    _globals["_ATTACHMENTUPDATERESPONSE"]._serialized_start = 1403
    _globals["_ATTACHMENTUPDATERESPONSE"]._serialized_end = 1574
    _globals["_ATTACHMENTDELETEREQUEST"]._serialized_start = 1576
    _globals["_ATTACHMENTDELETEREQUEST"]._serialized_end = 1669
    _globals["_ATTACHMENTDELETERESPONSE"]._serialized_start = 1671
    _globals["_ATTACHMENTDELETERESPONSE"]._serialized_end = 1772
    _globals["_ATTACHMENTSERVICE"]._serialized_start = 1775
    _globals["_ATTACHMENTSERVICE"]._serialized_end = 2388
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.clients import address_pb2 as _address_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Client(_message.Message):
    __slots__ = [
        "id",
        "name",
        "type_document",
        "document",
        "mobile",
        "email",
        "country",
        "addresses",
        "active",
        "external_id",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    MOBILE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    type_document: _base_pb2.Object
    document: str
    mobile: str
    email: str
    country: _base_pb2.Object
    addresses: _containers.RepeatedCompositeFieldContainer[_address_pb2.Address]
    active: bool
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        type_document: _Optional[_Union[_base_pb2.Object, _Mapping]] = ...,
        document: _Optional[str] = ...,
        mobile: _Optional[str] = ...,
        email: _Optional[str] = ...,
        country: _Optional[_Union[_base_pb2.Object, _Mapping]] = ...,
        addresses: _Optional[_Iterable[_Union[_address_pb2.Address, _Mapping]]] = ...,
        active: bool = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class ClientCreateRequest(_message.Message):
    __slots__ = ["name", "type_document", "document", "mobile", "email", "country", "external_id", "context"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    MOBILE_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    type_document: _base_pb2.Object
    document: str
    mobile: str
    email: str
    country: _base_pb2.Object
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        type_document: _Optional[_Union[_base_pb2.Object, _Mapping]] = ...,
        document: _Optional[str] = ...,
        mobile: _Optional[str] = ...,
        email: _Optional[str] = ...,
        country: _Optional[_Union[_base_pb2.Object, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ClientCreateResponse(_message.Message):
    __slots__ = ["response_standard", "client"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    client: Client
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        client: _Optional[_Union[Client, _Mapping]] = ...,
    ) -> None: ...

class ClientReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ClientReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "clients"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    clients: _containers.RepeatedCompositeFieldContainer[Client]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        clients: _Optional[_Iterable[_Union[Client, _Mapping]]] = ...,
    ) -> None: ...

class ClientUpdateRequest(_message.Message):
    __slots__ = ["client", "context"]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    client: Client
    context: _base_pb2.Context
    def __init__(
        self,
        client: _Optional[_Union[Client, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ClientUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "client"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    client: Client
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        client: _Optional[_Union[Client, _Mapping]] = ...,
    ) -> None: ...

class ClientDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class ClientDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import user_pb2 as v1_dot_stock_dot_user__pb2


class UserServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UserCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.user.UserService/UserCreate",
            request_serializer=v1_dot_stock_dot_user__pb2.UserCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_user__pb2.UserCreateResponse.FromString,
        )
        self.UserRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.user.UserService/UserRead",
            request_serializer=v1_dot_stock_dot_user__pb2.UserReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_user__pb2.UserReadResponse.FromString,
        )
        self.UserUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.user.UserService/UserUpdate",
            request_serializer=v1_dot_stock_dot_user__pb2.UserUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_user__pb2.UserUpdateResponse.FromString,
        )
        self.UserDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.user.UserService/UserDelete",
            request_serializer=v1_dot_stock_dot_user__pb2.UserDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_user__pb2.UserDeleteResponse.FromString,
        )


class UserServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UserCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UserDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "UserCreate": grpc.unary_unary_rpc_method_handler(
            servicer.UserCreate,
            request_deserializer=v1_dot_stock_dot_user__pb2.UserCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_user__pb2.UserCreateResponse.SerializeToString,
        ),
        "UserRead": grpc.unary_unary_rpc_method_handler(
            servicer.UserRead,
            request_deserializer=v1_dot_stock_dot_user__pb2.UserReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_user__pb2.UserReadResponse.SerializeToString,
        ),
        "UserUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.UserUpdate,
            request_deserializer=v1_dot_stock_dot_user__pb2.UserUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_user__pb2.UserUpdateResponse.SerializeToString,
        ),
        "UserDelete": grpc.unary_unary_rpc_method_handler(
            servicer.UserDelete,
            request_deserializer=v1_dot_stock_dot_user__pb2.UserDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_user__pb2.UserDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.user.UserService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class UserService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UserCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.user.UserService/UserCreate",
            v1_dot_stock_dot_user__pb2.UserCreateRequest.SerializeToString,
            v1_dot_stock_dot_user__pb2.UserCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.user.UserService/UserRead",
            v1_dot_stock_dot_user__pb2.UserReadRequest.SerializeToString,
            v1_dot_stock_dot_user__pb2.UserReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.user.UserService/UserUpdate",
            v1_dot_stock_dot_user__pb2.UserUpdateRequest.SerializeToString,
            v1_dot_stock_dot_user__pb2.UserUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UserDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.user.UserService/UserDelete",
            v1_dot_stock_dot_user__pb2.UserDeleteRequest.SerializeToString,
            v1_dot_stock_dot_user__pb2.UserDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import state_pb2 as v1_dot_sales_dot_state__pb2


class StateServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StateCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.state.StateService/StateCreate",
            request_serializer=v1_dot_sales_dot_state__pb2.StateCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_state__pb2.StateCreateResponse.FromString,
        )
        self.StateRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.state.StateService/StateRead",
            request_serializer=v1_dot_sales_dot_state__pb2.StateReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_state__pb2.StateReadResponse.FromString,
        )
        self.StateUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.state.StateService/StateUpdate",
            request_serializer=v1_dot_sales_dot_state__pb2.StateUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_state__pb2.StateUpdateResponse.FromString,
        )
        self.StateDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.state.StateService/StateDelete",
            request_serializer=v1_dot_sales_dot_state__pb2.StateDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_state__pb2.StateDeleteResponse.FromString,
        )


class StateServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StateCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StateRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StateUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StateDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "StateCreate": grpc.unary_unary_rpc_method_handler(
            servicer.StateCreate,
            request_deserializer=v1_dot_sales_dot_state__pb2.StateCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_state__pb2.StateCreateResponse.SerializeToString,
        ),
        "StateRead": grpc.unary_unary_rpc_method_handler(
            servicer.StateRead,
            request_deserializer=v1_dot_sales_dot_state__pb2.StateReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_state__pb2.StateReadResponse.SerializeToString,
        ),
        "StateUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.StateUpdate,
            request_deserializer=v1_dot_sales_dot_state__pb2.StateUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_state__pb2.StateUpdateResponse.SerializeToString,
        ),
        "StateDelete": grpc.unary_unary_rpc_method_handler(
            servicer.StateDelete,
            request_deserializer=v1_dot_sales_dot_state__pb2.StateDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_state__pb2.StateDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.state.StateService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class StateService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StateCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.state.StateService/StateCreate",
            v1_dot_sales_dot_state__pb2.StateCreateRequest.SerializeToString,
            v1_dot_sales_dot_state__pb2.StateCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StateRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.state.StateService/StateRead",
            v1_dot_sales_dot_state__pb2.StateReadRequest.SerializeToString,
            v1_dot_sales_dot_state__pb2.StateReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StateUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.state.StateService/StateUpdate",
            v1_dot_sales_dot_state__pb2.StateUpdateRequest.SerializeToString,
            v1_dot_sales_dot_state__pb2.StateUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StateDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.state.StateService/StateDelete",
            v1_dot_sales_dot_state__pb2.StateDeleteRequest.SerializeToString,
            v1_dot_sales_dot_state__pb2.StateDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/python_code.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1av1/rules/python_code.proto\x12%pro.omni.oms.api.v1.rules.python_code\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x91\x01\n\nPythonCode\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bpython_code\x18\x03 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x83\x01\n\x11PythonCodeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bpython_code\x18\x02 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x12PythonCodeResponse\x12\x46\n\x0bpython_code\x18\x01 \x01(\x0b\x32\x31.pro.omni.oms.api.v1.rules.python_code.PythonCode\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf3\x02\n\x15PythonCodeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n\x16PythonCodeReadResponse\x12G\n\x0cpython_codes\x18\x01 \x03(\x0b\x32\x31.pro.omni.oms.api.v1.rules.python_code.PythonCode\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x99\x01\n\x17PythonCodeUpdateRequest\x12\x46\n\x0bpython_code\x18\x01 \x01(\x0b\x32\x31.pro.omni.oms.api.v1.rules.python_code.PythonCode\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xad\x01\n\x18PythonCodeUpdateResponse\x12\x46\n\x0bpython_code\x18\x01 \x01(\x0b\x32\x31.pro.omni.oms.api.v1.rules.python_code.PythonCode\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"]\n\x17PythonCodeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"e\n\x18PythonCodeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe1\x04\n\x11PythonCodeService\x12\x89\x01\n\x10PythonCodeCreate\x12\x38.pro.omni.oms.api.v1.rules.python_code.PythonCodeRequest\x1a\x39.pro.omni.oms.api.v1.rules.python_code.PythonCodeResponse"\x00\x12\x8f\x01\n\x0ePythonCodeRead\x12<.pro.omni.oms.api.v1.rules.python_code.PythonCodeReadRequest\x1a=.pro.omni.oms.api.v1.rules.python_code.PythonCodeReadResponse"\x00\x12\x95\x01\n\x10PythonCodeUpdate\x12>.pro.omni.oms.api.v1.rules.python_code.PythonCodeUpdateRequest\x1a?.pro.omni.oms.api.v1.rules.python_code.PythonCodeUpdateResponse"\x00\x12\x95\x01\n\x10PythonCodeDelete\x12>.pro.omni.oms.api.v1.rules.python_code.PythonCodeDeleteRequest\x1a?.pro.omni.oms.api.v1.rules.python_code.PythonCodeDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.python_code_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PYTHONCODE"]._serialized_start = 121
    _globals["_PYTHONCODE"]._serialized_end = 266
    _globals["_PYTHONCODEREQUEST"]._serialized_start = 269
    _globals["_PYTHONCODEREQUEST"]._serialized_end = 400
    _globals["_PYTHONCODERESPONSE"]._serialized_start = 403
    _globals["_PYTHONCODERESPONSE"]._serialized_end = 570
    _globals["_PYTHONCODEREADREQUEST"]._serialized_start = 573
    _globals["_PYTHONCODEREADREQUEST"]._serialized_end = 944
    _globals["_PYTHONCODEREADRESPONSE"]._serialized_start = 947
    _globals["_PYTHONCODEREADRESPONSE"]._serialized_end = 1178
    _globals["_PYTHONCODEUPDATEREQUEST"]._serialized_start = 1181
    _globals["_PYTHONCODEUPDATEREQUEST"]._serialized_end = 1334
    _globals["_PYTHONCODEUPDATERESPONSE"]._serialized_start = 1337
    _globals["_PYTHONCODEUPDATERESPONSE"]._serialized_end = 1510
    _globals["_PYTHONCODEDELETEREQUEST"]._serialized_start = 1512
    _globals["_PYTHONCODEDELETEREQUEST"]._serialized_end = 1605
    _globals["_PYTHONCODEDELETERESPONSE"]._serialized_start = 1607
    _globals["_PYTHONCODEDELETERESPONSE"]._serialized_end = 1708
    _globals["_PYTHONCODESERVICE"]._serialized_start = 1711
    _globals["_PYTHONCODESERVICE"]._serialized_end = 2320
# @@protoc_insertion_point(module_scope)



from google.protobuf import json_format, struct_pb2
from pymongo.cursor import Cursor


# FIXME: change param including_default_value_fields to default_values when invoking util.MessageToDict
def MessageToDict(message, default_values=False, including_default_value_fields=False, **kwargs):
    """
    Converts protobuf message to a JSON dictionary considering the preserving proto field names.
    @param message: The protobuf message to convert.
    @param default_values: If True, fields with default values will be included in the dictionary.
    @param kwargs: Additional arguments to pass to json_format.MessageToDict.
    @return: The JSON dictionary.
    """
    return json_format.MessageToDict(
        message,
        preserving_proto_field_name=True,
        including_default_value_fields=default_values or including_default_value_fields,
        **kwargs,
    )


def format_request(data, request, proto, **kwargs) -> object:
    return json_format.ParseDict(data, getattr(proto, request)(), **kwargs)


def to_value(obj):
    """
    Use condictional expression to convert a object to a `Value`.
    """
    if isinstance(obj, dict):
        if "_id" in obj:
            obj["id"] = obj.pop("_id")
        return struct_pb2.Value(struct_value=to_struct(obj))
    elif isinstance(obj, list) or isinstance(obj, Cursor):
        return struct_pb2.Value(list_value=to_list_value(obj))
    elif isinstance(obj, bool):
        return struct_pb2.Value(bool_value=obj)
    elif isinstance(obj, int) or isinstance(obj, float):
        return struct_pb2.Value(number_value=obj)
    elif obj is None:
        return struct_pb2.Value(null_value=struct_pb2.NullValue.NULL_VALUE)
    else:
        return struct_pb2.Value(string_value=str(obj))


def to_struct(d):
    return struct_pb2.Struct(fields={k: to_value(v) for k, v in d.items()})


def to_list_value(lst):
    """Converts a list of dictionaries to a `ListValue`.

    Args:
      lst: A list of dictionaries.

    Returns:
      A `ListValue`.
    """
    return struct_pb2.ListValue(values=[to_value(x) for x in lst])



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/calculate_delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(v1/rules/calculate_delivery_method.proto\x12\x33pro.omni.oms.api.v1.rules.calculate_delivery_method\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto"\xa7\x01\n\x1b\x43\x61lculateDeliveryMethodData\x12-\n\x0c\x63\x61rt_details\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x10shipping_details\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct"\xb8\x01\n\x1e\x43\x61lculateDeliveryMethodRequest\x12^\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32P.pro.omni.oms.api.v1.rules.calculate_delivery_method.CalculateDeliveryMethodData\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x98\x01\n\x1f\x43\x61lculateDeliveryMethodResponse\x12*\n\x06result\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe9\x01\n\x1e\x43\x61lculateDeliveryMethodService\x12\xc6\x01\n\x17\x43\x61lculateDeliveryMethod\x12S.pro.omni.oms.api.v1.rules.calculate_delivery_method.CalculateDeliveryMethodRequest\x1aT.pro.omni.oms.api.v1.rules.calculate_delivery_method.CalculateDeliveryMethodResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.calculate_delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CALCULATEDELIVERYMETHODDATA"]._serialized_start = 179
    _globals["_CALCULATEDELIVERYMETHODDATA"]._serialized_end = 346
    _globals["_CALCULATEDELIVERYMETHODREQUEST"]._serialized_start = 349
    _globals["_CALCULATEDELIVERYMETHODREQUEST"]._serialized_end = 533
    _globals["_CALCULATEDELIVERYMETHODRESPONSE"]._serialized_start = 536
    _globals["_CALCULATEDELIVERYMETHODRESPONSE"]._serialized_end = 688
    _globals["_CALCULATEDELIVERYMETHODSERVICE"]._serialized_start = 691
    _globals["_CALCULATEDELIVERYMETHODSERVICE"]._serialized_end = 924
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import delivery_category_pb2 as v1_dot_rules_dot_delivery__category__pb2
from omni.pro.protos.v1.rules import delivery_locality_pb2 as v1_dot_rules_dot_delivery__locality__pb2
from omni.pro.protos.v1.rules import delivery_schedule_pb2 as v1_dot_rules_dot_delivery__schedule__pb2
from omni.pro.protos.v1.rules import delivery_warehouse_pb2 as v1_dot_rules_dot_delivery__warehouse__pb2
from omni.pro.protos.v1.rules import location_pb2 as v1_dot_rules_dot_location__pb2
from omni.pro.protos.v1.rules import stock_security_pb2 as v1_dot_rules_dot_stock__security__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ev1/rules/delivery_method.proto\x12)pro.omni.oms.api.v1.rules.delivery_method\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/rules/warehouse.proto\x1a\x17v1/rules/location.proto\x1a!v1/rules/delivery_warehouse.proto\x1a v1/rules/delivery_category.proto\x1a v1/rules/delivery_locality.proto\x1a v1/rules/delivery_schedule.proto\x1a\x1dv1/rules/stock_security.proto"\xc8\x07\n\x0e\x44\x65liveryMethod\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12K\n\x13\x64\x65livery_warehouses\x18\x03 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12\x1d\n\x15type_picking_transfer\x18\x04 \x01(\t\x12\x1f\n\x17validate_warehouse_code\x18\x05 \x01(\t\x12\x19\n\x11quantity_security\x18\x06 \x01(\x02\x12\x0c\n\x04\x63ode\x18\x07 \x01(\t\x12\x15\n\rtype_delivery\x18\x08 \x01(\t\x12G\n\x11\x64\x65livery_location\x18\t \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12Z\n\x11transfer_template\x18\n \x01(\x0b\x32?.pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouse\x12X\n\x11\x63\x61tegory_template\x18\x0b \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategory\x12Y\n\x12locality_available\x18\x0c \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocality\x12X\n\x11schedule_template\x18\r \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_schedule.DeliverySchedule\x12O\n\x0estock_security\x18\x0e \x01(\x0b\x32\x37.pro.omni.oms.api.v1.rules.stock_security.StockSecurity\x12H\n$transfer_between_delivery_warehouses\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x11 \x01(\t\x12?\n\x0cobject_audit\x18\x12 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x94\x04\n\x1b\x44\x65liveryMethodCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x15type_picking_transfer\x18\x02 \x01(\t\x12\x1f\n\x17validate_warehouse_code\x18\x03 \x01(\t\x12\x19\n\x11quantity_security\x18\x04 \x01(\x02\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x15\n\rtype_delivery\x18\x06 \x01(\t\x12\x1c\n\x14\x64\x65livery_location_id\x18\x07 \x01(\x05\x12\x1c\n\x14transfer_template_id\x18\x08 \x01(\t\x12\x1c\n\x14\x63\x61tegory_template_id\x18\t \x01(\t\x12\x1d\n\x15locality_available_id\x18\n \x01(\t\x12\x1c\n\x14schedule_template_id\x18\x0b \x01(\t\x12\x19\n\x11stock_security_id\x18\x0c \x01(\t\x12\x1e\n\x16\x64\x65livery_warehouse_ids\x18\r \x03(\x05\x12H\n$transfer_between_delivery_warehouses\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0f \x01(\t\x12\x36\n\x07\x63ontext\x18\x10 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1c\x44\x65liveryMethodCreateResponse\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf7\x02\n\x19\x44\x65liveryMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf7\x01\n\x1a\x44\x65liveryMethodReadResponse\x12S\n\x10\x64\x65livery_methods\x18\x01 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa9\x01\n\x1b\x44\x65liveryMethodUpdateRequest\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1c\x44\x65liveryMethodUpdateResponse\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"a\n\x1b\x44\x65liveryMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"i\n\x1c\x44\x65liveryMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x91\x01\n\x1b\x41\x64\x64\x44\x65liveryWarehouseRequest\x12\x1a\n\x12\x64\x65livery_method_id\x18\x01 \x01(\t\x12\x1e\n\x16\x64\x65livery_warehouse_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1c\x41\x64\x64\x44\x65liveryWarehouseResponse\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x94\x01\n\x1eRemoveDeliveryWarehouseRequest\x12\x1a\n\x12\x64\x65livery_method_id\x18\x01 \x01(\t\x12\x1e\n\x16\x64\x65livery_warehouse_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc0\x01\n\x1fRemoveDeliveryWarehouseResponse\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xa2\x08\n\x15\x44\x65liveryMethodService\x12\xa9\x01\n\x14\x44\x65liveryMethodCreate\x12\x46.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodCreateRequest\x1aG.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodCreateResponse"\x00\x12\xa3\x01\n\x12\x44\x65liveryMethodRead\x12\x44.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodReadRequest\x1a\x45.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodReadResponse"\x00\x12\xa9\x01\n\x14\x44\x65liveryMethodUpdate\x12\x46.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodUpdateRequest\x1aG.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodUpdateResponse"\x00\x12\xa9\x01\n\x14\x44\x65liveryMethodDelete\x12\x46.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodDeleteRequest\x1aG.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethodDeleteResponse"\x00\x12\xa9\x01\n\x14\x41\x64\x64\x44\x65liveryWarehouse\x12\x46.pro.omni.oms.api.v1.rules.delivery_method.AddDeliveryWarehouseRequest\x1aG.pro.omni.oms.api.v1.rules.delivery_method.AddDeliveryWarehouseResponse"\x00\x12\xb2\x01\n\x17RemoveDeliveryWarehouse\x12I.pro.omni.oms.api.v1.rules.delivery_method.RemoveDeliveryWarehouseRequest\x1aJ.pro.omni.oms.api.v1.rules.delivery_method.RemoveDeliveryWarehouseResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYMETHOD"]._serialized_start = 348
    _globals["_DELIVERYMETHOD"]._serialized_end = 1316
    _globals["_DELIVERYMETHODCREATEREQUEST"]._serialized_start = 1319
    _globals["_DELIVERYMETHODCREATEREQUEST"]._serialized_end = 1851
    _globals["_DELIVERYMETHODCREATERESPONSE"]._serialized_start = 1854
    _globals["_DELIVERYMETHODCREATERESPONSE"]._serialized_end = 2043
    _globals["_DELIVERYMETHODREADREQUEST"]._serialized_start = 2046
    _globals["_DELIVERYMETHODREADREQUEST"]._serialized_end = 2421
    _globals["_DELIVERYMETHODREADRESPONSE"]._serialized_start = 2424
    _globals["_DELIVERYMETHODREADRESPONSE"]._serialized_end = 2671
    _globals["_DELIVERYMETHODUPDATEREQUEST"]._serialized_start = 2674
    _globals["_DELIVERYMETHODUPDATEREQUEST"]._serialized_end = 2843
    _globals["_DELIVERYMETHODUPDATERESPONSE"]._serialized_start = 2846
    _globals["_DELIVERYMETHODUPDATERESPONSE"]._serialized_end = 3035
    _globals["_DELIVERYMETHODDELETEREQUEST"]._serialized_start = 3037
    _globals["_DELIVERYMETHODDELETEREQUEST"]._serialized_end = 3134
    _globals["_DELIVERYMETHODDELETERESPONSE"]._serialized_start = 3136
    _globals["_DELIVERYMETHODDELETERESPONSE"]._serialized_end = 3241
    _globals["_ADDDELIVERYWAREHOUSEREQUEST"]._serialized_start = 3244
    _globals["_ADDDELIVERYWAREHOUSEREQUEST"]._serialized_end = 3389
    _globals["_ADDDELIVERYWAREHOUSERESPONSE"]._serialized_start = 3392
    _globals["_ADDDELIVERYWAREHOUSERESPONSE"]._serialized_end = 3581
    _globals["_REMOVEDELIVERYWAREHOUSEREQUEST"]._serialized_start = 3584
    _globals["_REMOVEDELIVERYWAREHOUSEREQUEST"]._serialized_end = 3732
    _globals["_REMOVEDELIVERYWAREHOUSERESPONSE"]._serialized_start = 3735
    _globals["_REMOVEDELIVERYWAREHOUSERESPONSE"]._serialized_end = 3927
    _globals["_DELIVERYMETHODSERVICE"]._serialized_start = 3930
    _globals["_DELIVERYMETHODSERVICE"]._serialized_end = 4988
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/tax.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12v1/sales/tax.proto\x12\x1dpro.omni.oms.api.v1.sales.tax\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xaf\x01\n\x03Tax\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"{\n\x10TaxCreateRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8f\x01\n\x11TaxCreateResponse\x12/\n\x03tax\x18\x01 \x01(\x0b\x32".pro.omni.oms.api.v1.sales.tax.Tax\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xec\x02\n\x0eTaxReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc8\x01\n\x0fTaxReadResponse\x12/\n\x03tax\x18\x01 \x03(\x0b\x32".pro.omni.oms.api.v1.sales.tax.Tax\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"{\n\x10TaxUpdateRequest\x12/\n\x03tax\x18\x01 \x01(\x0b\x32".pro.omni.oms.api.v1.sales.tax.Tax\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8f\x01\n\x11TaxUpdateResponse\x12/\n\x03tax\x18\x01 \x01(\x0b\x32".pro.omni.oms.api.v1.sales.tax.Tax\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"V\n\x10TaxDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"^\n\x11TaxDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xce\x03\n\nTaxService\x12p\n\tTaxCreate\x12/.pro.omni.oms.api.v1.sales.tax.TaxCreateRequest\x1a\x30.pro.omni.oms.api.v1.sales.tax.TaxCreateResponse"\x00\x12j\n\x07TaxRead\x12-.pro.omni.oms.api.v1.sales.tax.TaxReadRequest\x1a..pro.omni.oms.api.v1.sales.tax.TaxReadResponse"\x00\x12p\n\tTaxUpdate\x12/.pro.omni.oms.api.v1.sales.tax.TaxUpdateRequest\x1a\x30.pro.omni.oms.api.v1.sales.tax.TaxUpdateResponse"\x00\x12p\n\tTaxDelete\x12/.pro.omni.oms.api.v1.sales.tax.TaxDeleteRequest\x1a\x30.pro.omni.oms.api.v1.sales.tax.TaxDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.tax_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TAX"]._serialized_start = 105
    _globals["_TAX"]._serialized_end = 280
    _globals["_TAXCREATEREQUEST"]._serialized_start = 282
    _globals["_TAXCREATEREQUEST"]._serialized_end = 405
    _globals["_TAXCREATERESPONSE"]._serialized_start = 408
    _globals["_TAXCREATERESPONSE"]._serialized_end = 551
    _globals["_TAXREADREQUEST"]._serialized_start = 554
    _globals["_TAXREADREQUEST"]._serialized_end = 918
    _globals["_TAXREADRESPONSE"]._serialized_start = 921
    _globals["_TAXREADRESPONSE"]._serialized_end = 1121
    _globals["_TAXUPDATEREQUEST"]._serialized_start = 1123
    _globals["_TAXUPDATEREQUEST"]._serialized_end = 1246
    _globals["_TAXUPDATERESPONSE"]._serialized_start = 1249
    _globals["_TAXUPDATERESPONSE"]._serialized_end = 1392
    _globals["_TAXDELETEREQUEST"]._serialized_start = 1394
    _globals["_TAXDELETEREQUEST"]._serialized_end = 1480
    _globals["_TAXDELETERESPONSE"]._serialized_start = 1482
    _globals["_TAXDELETERESPONSE"]._serialized_end = 1576
    _globals["_TAXSERVICE"]._serialized_start = 1579
    _globals["_TAXSERVICE"]._serialized_end = 2041
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Compute(_message.Message):
    __slots__ = [
        "id",
        "data_request",
        "data_process",
        "data_response_internal",
        "data_response_external",
        "time",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    DATA_REQUEST_FIELD_NUMBER: _ClassVar[int]
    DATA_PROCESS_FIELD_NUMBER: _ClassVar[int]
    DATA_RESPONSE_INTERNAL_FIELD_NUMBER: _ClassVar[int]
    DATA_RESPONSE_EXTERNAL_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    data_request: str
    data_process: str
    data_response_internal: str
    data_response_external: str
    time: float
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        data_request: _Optional[str] = ...,
        data_process: _Optional[str] = ...,
        data_response_internal: _Optional[str] = ...,
        data_response_external: _Optional[str] = ...,
        time: _Optional[float] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class ComputeCreateRequest(_message.Message):
    __slots__ = ["data_request", "data_process", "data_response_internal", "data_response_external", "time", "context"]
    DATA_REQUEST_FIELD_NUMBER: _ClassVar[int]
    DATA_PROCESS_FIELD_NUMBER: _ClassVar[int]
    DATA_RESPONSE_INTERNAL_FIELD_NUMBER: _ClassVar[int]
    DATA_RESPONSE_EXTERNAL_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    data_request: str
    data_process: str
    data_response_internal: str
    data_response_external: str
    time: float
    context: _base_pb2.Context
    def __init__(
        self,
        data_request: _Optional[str] = ...,
        data_process: _Optional[str] = ...,
        data_response_internal: _Optional[str] = ...,
        data_response_external: _Optional[str] = ...,
        time: _Optional[float] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ComputeCreateResponse(_message.Message):
    __slots__ = ["response_standard", "compute"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    compute: Compute
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        compute: _Optional[_Union[Compute, _Mapping]] = ...,
    ) -> None: ...

class ComputeReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ComputeReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "compute"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    compute: _containers.RepeatedCompositeFieldContainer[Compute]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        compute: _Optional[_Iterable[_Union[Compute, _Mapping]]] = ...,
    ) -> None: ...

class ComputeUpdateRequest(_message.Message):
    __slots__ = ["compute", "context"]
    COMPUTE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    compute: Compute
    context: _base_pb2.Context
    def __init__(
        self,
        compute: _Optional[_Union[Compute, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ComputeUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "compute"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    compute: Compute
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        compute: _Optional[_Union[Compute, _Mapping]] = ...,
    ) -> None: ...

class ComputeDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class ComputeDeleteResponse(_message.Message):
    __slots__ = ["response_standard", "compute"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    compute: Compute
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        compute: _Optional[_Union[Compute, _Mapping]] = ...,
    ) -> None: ...
